@@ -2,11 +2,11 @@
 
 from django.db import models
 from django.conf import settings
+AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
+
 
 from phonenumber_field.modelfields import PhoneNumberField
 
-from django_twilio.compat import AUTH_USER_MODEL
-
 
 class Caller(models.Model):
     """ A caller is defined uniquely by their phone number.
@@ -17,7 +17,7 @@ class Caller(models.Model):
         <http://en.wikipedia.org/wiki/E.164>`_ format.
 
     """
-    blacklisted = models.BooleanField()
+    blacklisted = models.BooleanField(default=False)
     phone_number = PhoneNumberField(unique=True)
 
     def __unicode__(self):
